OC.L10N.register(
    "core",
    {
    "Please select a file." : "Pasirinkite failą.",
    "File is too big" : "Failas yra per didelis",
    "The selected file is not an image." : "Pasirinktas failas nėra paveikslas.",
    "The selected file cannot be read." : "Nepavyksta perskaityti pasirinkto failo.",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko rašyti į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "Invalid file provided" : "Pateiktas neteisingas failas",
    "No image or file provided" : "Nenurodytas paveikslas ar failas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
    "Invalid image" : "Netinkamas paveikslas",
    "No temporary profile picture available, try again" : "Nėra laikinojo profilio paveikslėlio, bandykite dar kartą",
    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
    "No valid crop data provided" : "Pateikti neteisingi apkirpimo duomenys",
    "Crop is not square" : "Apkirpimo plotas nėra kvadratas",
    "State token does not match" : "Išorinės sistemos leidimai nesutampa su turimais.",
    "Invalid app password" : "Neteisingas programėlės slaptažodis",
    "Could not complete login" : "Nepavyko užbaigti prisijungimo",
    "Your login token is invalid or has expired" : "Jūsų prieigos raktas yra neteisingas arba pasibaigė jo galiojimo laikas",
    "Login" : "Prisijungti",
    "Password reset is disabled" : "Slaptažodžio atstatymas išjungtas",
    "Could not reset password because the token is expired" : "Nepavyko atstatyti slaptažodžio, nes prieigos raktas nebegalioja",
    "Could not reset password because the token is invalid" : "Nepavyko atstatyti slaptažodžio, nes prieigos raktas yra neteisingas",
    "%s password reset" : "%s slaptažodžio atstatymas",
    "Password reset" : "Slaptažodžio atstatymas",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite mygtuką slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite nuorodą slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
    "Reset your password" : "Atkurkite savo slaptažodį",
    "Nextcloud Server" : "Nextcloud serveris",
    "The user limit of this instance is reached." : "Yra pasiekta šio egzemplioriaus naudotojų riba.",
    "Learn more ↗" : "Sužinokite daugiau ↗",
    "Preparing update" : "Ruošiamas atnaujinimas",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Pataisymo žingsnis:",
    "Repair info:" : "Pataisymo informacija:",
    "Repair warning:" : "Taisymo įspėjimas:",
    "Repair error:" : "Taisymo klaida:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Automatinis atnaujinimas išjungtas config.php faile. Naudokite komandinės eilutės atnaujinimo įrankį.",
    "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
    "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
    "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
    "Updated database" : "Atnaujinta duomenų bazė",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tikrinama ar %s duomenų bazės struktūra gali būti atnaujinta (priklausomai nuo duomenų bazės dydžio, tai gali ilgai užtrukti)",
    "Updated \"%1$s\" to %2$s" : "Atnaujinta „%1$s“ į %2$s",
    "Set log level to debug" : "Žurnalo išvesties lygis nustatytas į derinimo",
    "Reset log level" : "Atstatytas registravimo lygis",
    "Starting code integrity check" : "Pradedama kodo vientisumo patikra",
    "Finished code integrity check" : "Kodo vientisumo patikra užbaigta",
    "%s (incompatible)" : "%s (nesuderinama)",
    "The following apps have been disabled: %s" : "Šios programėlės buvo išjungtos: %s",
    "Already up to date" : "Naudojama naujausia versija",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Buvo neįmanoma įvykdyti cron užduotį per komandų eilutę. Atsirado šios techninės klaidos:",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Lentelėje „{tableName}“ trūksta nebūtino stulpelio „{columnName}“.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Šiame egzemplioriuje trūksta kai kurių rekomenduojamų PHP modulių. Pagerintam našumui ir geresniam suderinamumui yra primygtinai rekomenduojama juos įdiegti.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Tai ypač rekomenduojama failų sinchronizavimui naudojant darbalaukio kliento programą.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Išsamesnei informacijai, žiūrėkite {linkstart}dokumentaciją ↗{linkend}.",
    "unknown text" : "nežinomas tekstas",
    "Hello world!" : "Sveikas, pasauli!",
    "sunny" : "saulėta",
    "Hello {name}, the weather is {weather}" : "Sveiki {name}, šiandien yra {weather}",
    "Hello {name}" : "Sveiki, {name},",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
    "new" : "naujas",
    "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Vykdomas atnaujinimas, palikus šį puslapį atvertą, kai kuriose aplinkose šis procesas gali būti nutrauktas.",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "An error occurred." : "Įvyko klaida.",
    "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atnaujinimas buvo nesėkmingas. Išsamesnei informacijai apie šią problemą, <a href=\"{url}\">žiūrėkite įrašą mūsų forume</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
    "More apps" : "Daugiau programėlių",
    "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
    "Log in" : "Prisijungti",
    "Logging in …" : "Prisijungiama …",
    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
    "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
    "An internal error occurred." : "Įvyko vidinė klaida.",
    "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
    "Password" : "Slaptažodis",
    "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
    "User disabled" : "Naudotojas išjungtas",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
    "Username or email" : "Naudotojas arba el. paštas",
    "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
    "Browser not supported" : "Naršyklė nepalaikoma",
    "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
    "Your connection is not secure" : "Jūsų ryšys nėra saugus",
    "Passwordless authentication is only available over a secure connection." : "Tapatybės nustatymas be slaptažodžio yra prieinamas tik per saugų ryšį.",
    "Reset password" : "Atstatyti slaptažodį",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
    "Back to login" : "Grįžti prie prisijungimo",
    "New password" : "Naujas slaptažodis",
    "I know what I'm doing" : "Aš žinau ką darau",
    "Recommended apps" : "Rekomenduojamos programėlės",
    "Loading apps …" : "Įkeliamos programėlės…",
    "Installing apps …" : "Įdiegiamos programėlės…",
    "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
    "Skip" : "Praleisti",
    "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
    "Forgot password?" : "Pamiršote slaptažodį?",
    "Log in with a device" : "Prisijungti naudojant įrenginį",
    "Back" : "Atgal",
    "Edit Profile" : "Taisyti profilį",
    "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
    "You have not added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
    "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
    "Reset search" : "Atstatyti paiešką",
    "Search for {name} only" : "Ieškoti tik {name}",
    "No results for {query}" : "{query} negrąžino jokių rezultatų",
    "Start typing to search" : "Norėdami atlikti paiešką, pradėkite rašyti",
    "Loading more results …" : "Įkeliama daugiau rezultatų…",
    "Load more results" : "Įkelti daugiau rezultatų",
    "Search" : "Ieškoti",
    "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
    "Search {types} …" : "Ieškoti {types}…",
    "Settings" : "Nustatymai",
    "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
    "Search contacts …" : "Ieškoti adresatų…",
    "No contacts found" : "Adresatų nerasta",
    "Show all contacts …" : "Rodyti visus adresatus...",
    "Install the Contacts app" : "Įdiegti adresatų programėlę",
    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
    "Looking for {term} …" : "Ieškoma {term} ...",
    "No" : "Ne",
    "Yes" : "Taip",
    "No files in here" : "Čia failų nėra",
    "New folder" : "Naujas aplankas",
    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeista",
    "\"{name}\" is an invalid file name." : "„{name}“ yra neteisingas failo pavadinimas.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" yra neleistinas failo tipas",
    "{newName} already exists" : "{newName} jau yra",
    "Choose" : "Pasirinkti",
    "Copy" : "Kopijuoti",
    "Move" : "Perkelti",
    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
    "OK" : "Gerai",
    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
    "read-only" : "tik skaitymui",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failų konfliktas","{count} failų konfliktai","{count} failų konfliktų","{count} failų konfliktas"],
    "One file conflict" : "Vieno failo konfliktas",
    "New Files" : "Nauji failai",
    "Already existing files" : "Jau esami failai",
    "Which files do you want to keep?" : "Kuriuos failus norite pasilikti?",
    "If you select both versions, the copied file will have a number added to its name." : "Jei pasiliekate abi versijas, prie nukopijuoto failo pavadinimo bus pridėtas skaičius.",
    "Cancel" : "Atsisakyti",
    "Continue" : "Tęsti",
    "(all selected)" : "(visi pažymėti)",
    "({count} selected)" : "({count} pažymėtų)",
    "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
    "Show list view" : "Rodyti sąrašo rodinį",
    "Show grid view" : "Rodyti tinklelio rodinį",
    "Pending" : "Vykdoma",
    "Copy to {folder}" : "Kopijuoti į {folder}",
    "Move to {folder}" : "Perkelti į {folder}",
    "Saving …" : "Įrašoma …",
    "Authentication required" : "Reikalingas tapatybės nustatymas",
    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
    "Confirm" : "Patvirtinti",
    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
    "seconds ago" : "prieš keletą sekundžių",
    "Connection to server lost" : "Ryšys su serveriu nutrūko",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
    "Add to a project" : "Pridėti į projektą",
    "Show details" : "Rodyti išsamiau",
    "Hide details" : "Slėpti išsamesnę informaciją",
    "Rename project" : "Pervadinti projektą",
    "Failed to rename the project" : "Nepavyko pervadinti projekto",
    "Failed to create a project" : "Nepavyko sukurti projekto",
    "Failed to add the item to the project" : "Nepavyko pridėti elemento į projektą",
    "Connect items to a project to make them easier to find" : "Susieti elementus su projektu, kad juos būtų lengviau rasti",
    "Type to search for existing projects" : "Rašykite norėdami ieškoti esamų projektų",
    "New in" : "Nauja",
    "View changelog" : "Rodyti keitinių žurnalą",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "No action available" : "Jokie veiksmai negalimi",
    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
    "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
    "Restricted" : "Apribota",
    "Invisible" : "Nematomas",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "Collaborative tags" : "Bendradarbiavimo žymės",
    "No tags found" : "Nerasta jokių žymių",
    "Personal" : "Asmeniniai",
    "Users" : "Naudotojai",
    "Apps" : "Programėlės",
    "Admin" : "Administravimas",
    "Help" : "Pagalba",
    "Access forbidden" : "Prieiga uždrausta",
    "Profile not found" : "Profilis nerastas",
    "The profile does not exist." : "Profilio nėra.",
    "Back to %s" : "Atgal į %s",
    "Page not found" : "Puslapis nerastas",
    "Too many requests" : "Per daug užklausų",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
    "Error" : "Klaida",
    "Previous" : "Ankstesnis",
    "Internal Server Error" : "Vidinė serverio klaida",
    "The server was unable to complete your request." : "Serveriui nepavyko įvykdyti jūsų užklausos.",
    "If this happens again, please send the technical details below to the server administrator." : "Jei tai pasikartos, prašome nusiųsti serverio administratoriui žemiau esančią techninę informaciją.",
    "More details can be found in the server log." : "Detalesnė informacija yra sistemos žurnale.",
    "Technical details" : "Techniniai duomenys",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Type: %s" : "Tipas: %s",
    "Code: %s" : "Kodas: %s",
    "Message: %s" : "Žinutė: %s",
    "File: %s" : "Failas: %s",
    "Line: %s" : "Eilutė: %s",
    "Trace" : "Sekti",
    "Security warning" : "Saugumo įspėjimas",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
    "Create an <strong>admin account</strong>" : "Sukurkite <strong>administratoriaus paskyrą</strong>",
    "Username" : "Naudotojo vardas",
    "Show password" : "Rodyti slaptažodį",
    "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
    "Storage & database" : "Saugykla ir duomenų bazė",
    "Data folder" : "Duomenų aplankas",
    "Configure the database" : "Konfigūruokite duomenų bazę",
    "Only %s is available." : "Yra prieinama tik %s.",
    "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
    "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
    "Database user" : "Duomenų bazės naudotojas",
    "Database password" : "Duomenų bazės slaptažodis",
    "Database name" : "Duomenų bazės pavadinimas",
    "Database tablespace" : "Duomenų bazės loginis saugojimas",
    "Database host" : "Duomenų bazės serveris",
    "Performance warning" : "Sistemos našumo problemos perspėjimas",
    "You chose SQLite as database." : "Jūs kaip duomenų bazę pasirinkote SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite turėtų būti naudojama tik minimaliems ir plėtojimo egzemplioriams. Darbiniam egzemplioriui rekomenduojame naudoti kitą duomenų bazės vidinę pusę.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jei sinchronizavimui naudojate kliento programas, tuomet SQLite naudojimas yra primygtinai nerekomenduojamas.",
    "Install" : "Įdiegti",
    "Installing …" : "Įdiegiama…",
    "Need help?" : "Reikia pagalbos?",
    "See the documentation" : "Žiūrėkite dokumentaciją",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nepavyko iš konfigūracijos aplanko pašalinti failo CAN_INSTALL. Pašalinkite šį failą rankiniu būdu.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Sistemos veikimui reikalingas JavaScript palaikymas. Prašome {linkstart}įjungti JavaScript palaikymą{linkend} ir atnaujinti puslapį.",
    "Skip to main content" : "Pereiti į pagrindinį turinį",
    "Skip to navigation of app" : "Pereiti į programėlės naršymą",
    "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
    "Contacts" : "Adresatai",
    "Contacts menu" : "Adresatų meniu",
    "Open settings menu" : "Atverti nustatymų meniu",
    "Confirm your password" : "Patvirtinkite savo slaptažodį",
    "Connect to your account" : "Prisijunkite prie paskyros",
    "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeigu nebandote nusistatyti naujo įrenginio ar programėlės, tuomet kažkas bando jus apgauti, kad suteiktumėte jam prieigą prie savo duomenų. Tokiu atveju netęskite ir, vietoj to, susisiekite su savo sistemos administratoriumi.",
    "App token" : "Išorinės sistemos įskiepio kodas",
    "Grant access" : "Suteikti prieigą",
    "Alternative log in using app token" : "Alternatyvus prisijungimas naudojant programėlės atpažinimo raktą",
    "Account access" : "Paskyros prieiga",
    "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
    "Account connected" : "Paskyra prijungta",
    "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
    "You can close this window." : "Galite užverti šį langą.",
    "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
    "Email address" : "El. pašto adresas",
    "Password sent!" : "Slaptažodis išsiųstas!",
    "Go to %s" : "Pereiti į %s",
    "Two-factor authentication" : "Dviejų faktorių tapatybės nustatymas",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nepavyko įkelti bent vieno iš jūsų įjungtų dviejų faktorių tapatybės nustatymo metodų. Susisiekite su savo administratoriumi.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Susisiekite su savo administratoriumi dėl pagalbos. ",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Tęskite, norėdami nustatyti dviejų faktorių tapatybės nustatymą.",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Norėdami prisijungti, naudokite vieną iš savo atsarginių kodų arba susisiekite su savo administratoriumi dėl pagalbos. ",
    "Use backup code" : "Naudoti atsarginį kodą",
    "Cancel login" : "Atsisakyti prisijungimo",
    "Error while validating your second factor" : "Klaida patvirtinant jūsų antrąjį faktorių",
    "Access through untrusted domain" : "Prieiga iš nepatikimo domeno",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Susisiekite su savo administratoriumi. Jeigu jūs esate administratorius, pataisykite \"trusted_domains\" nustatymą config/config.php faile, kaip tai parodyta pavyzdyje, config.sample.php faile.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Tolimesnę informaciją apie tai, kaip tai konfigūruoti, galite rasti %1$sdokumentacijoje%2$s.",
    "App update required" : "Reikalingas programėlės atnaujinimas",
    "%1$s will be updated to version %2$s" : "%1$s bus atnaujinta į versiją %2$s",
    "The following apps will be updated:" : "Bus atnaujintos šios programėlės:",
    "These incompatible apps will be disabled:" : "Bus išjungtos šios nesuderinamos programėlės:",
    "The theme %s has been disabled." : "Apipavidalinimas %s buvo išjungtas.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prieš tęsdami, įsitikinkite, kad pasidarėte duomenų bazės, konfigūracijos aplanko bei duomenų aplanko atsarginę kopiją.",
    "Start update" : "Pradėti atnaujinimą",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Naudodami didesnius diegimus ir norėdami išvengti laukimo laiko, vietoj to, savo diegimo kataloge galite paleisti šią komandą:",
    "Detailed logs" : "Išsamūs žurnalai",
    "Update needed" : "Reikalingas atnaujinimas",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Naudokite komandų eilutės atnaujinimo programą, nes turite didelį egzempliorių su daugiau nei 50 naudotojų.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Prireikus pagalbos, žiūrėkite  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Suprantu, kad atnaujinimui naudodamas vartotojo aplinką, rizikuoju, kad sistemos darbas sutriks ir prisijungę vartotojai gali netekti duomenų, turiu atsarginę duomenų kopiją ir žinau, kaip atstatyti duomenis nesėkmės atveju.",
    "Upgrade via web on my own risk" : "Atnaujinti per interneto naršyklę prisiimant riziką",
    "Maintenance mode" : "Techninės priežiūros veiksena",
    "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
    "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tikrinama lentelė %s",
    "restricted" : "apribota",
    "invisible" : "nematoma",
    "File not found" : "Failas nerastas",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Nepavyko serveryje rasti dokumento. Galbūt, viešinys buvo ištrintas arba pasibaigė jo galiojimo laikas?",
    "More" : "Daugiau",
    "More apps menu" : "Daugiau programėlių meniu",
    "Settings menu" : "Nustatymų meniu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "You haven't added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
    "{user} hasn't added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
